Author: duncan
Date: Sat Oct  7 07:37:06 2006
New Revision: 8334

Modified:
   branches/rel-1-5/freevo/src/plugins/upsoon.py

Log:
Added a OSD_MESSAGE when the player is stopped.

Modified: branches/rel-1-5/freevo/src/plugins/upsoon.py
==============================================================================
--- branches/rel-1-5/freevo/src/plugins/upsoon.py       (original)
+++ branches/rel-1-5/freevo/src/plugins/upsoon.py       Sat Oct  7 07:37:06 2006
@@ -92,7 +92,7 @@
         _debug_('up=%s %s' % (self.serverup, self.next_program), dbglvl)
 
         self.fc = FreevoChannels()
-        self.seconds_before_start = 90
+        self.seconds_before_start = 60
 
 
     def findNextProgram(self):
@@ -188,7 +188,7 @@
 
         secs_to_next = self.next_program.start - config.TV_RECORD_PADDING_PRE 
- int(now + 0.5)
         _debug_('next recording in %s secs' % (secs_to_next), dbglvl)
         # stop the player 90 seconds before recording is due to start
         if (secs_to_next > self.seconds_before_start):
             return None
 
@@ -203,7 +203,8 @@
             except OSError:
                 rc.post_event(STOP)
                 _debug_('video device \"%s\" in use' % (vdev), dbglvl)
-                # Need to go back one menu
+                rc.post_event(Event(OSD_MESSAGE, arg=_('A recording will start 
in less than a minute')))
+                # The alert box doesn't work
                 #AlertBox(text=_('Sorry, a program is about to start 
recording. '), height=200).show()
             viddev.close()
         except:
@@ -218,7 +219,8 @@
             except OSError:
                 rc.post_event(STOP)
                 _debug_('radio device \"%s\" in use' % (rdev), dbglvl)
-                # Need to go back one menu
+                rc.post_event(Event(OSD_MESSAGE, arg=_('A recording will start 
in less than a minute')))
+                # Need to go back one menu, the alert box doesn't work
                 #AlertBox(text=_('Sorry, a program is about to start 
recording. '), height=200).show()
             viddev.close()
         except:

-------------------------------------------------------------------------
@@ -188,7 +188,7 @@
         _debug_('next recording in %s secs' % (secs_to_next), dbglvl)
-        # stop the player 90 seconds before recording is due to start
+        # stop the player 60 seconds before recording is due to start
         if (secs_to_next > self.seconds_before_start):
             return None
Take Surveys. Earn Cash. Influence the Future of IT
Join SourceForge.net's Techsay panel and you'll get the chance to share your
opinions on IT & business topics through brief surveys -- and earn cash
http://www.techsay.com/default.php?page=join.php&p=sourceforge&CID=DEVDEV
_______________________________________________
Freevo-cvslog mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/freevo-cvslog

Reply via email to